@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -137,6 +140,42 @@ class CloudFilestoreManagerAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return CloudFilestoreManagerClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> CloudFilestoreManagerTransport:
         """Returns the transport used by the client instance.
@@ -210,6 +249,27 @@ class CloudFilestoreManagerAsyncClient:
         r"""Lists all instances in a project for either a
         specified location or for all locations.
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_list_instances():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.ListInstancesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_instances(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.ListInstancesRequest, dict]):
                 The request object. ListInstancesRequest lists
@@ -241,7 +301,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -303,6 +363,25 @@ class CloudFilestoreManagerAsyncClient:
     ) -> cloud_filestore_service.Instance:
         r"""Gets the details of a specific instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_get_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.GetInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.GetInstanceRequest, dict]):
                 The request object. GetInstanceRequest gets the state of
@@ -325,7 +404,7 @@ class CloudFilestoreManagerAsyncClient:
                 A Cloud Filestore instance.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -387,6 +466,31 @@ class CloudFilestoreManagerAsyncClient:
         capacity of the backup (and also equal to or larger than
         the minimum capacity of the tier).
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_create_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.CreateInstanceRequest(
+                    parent="parent_value",
+                    instance_id="instance_id_value",
+                )
+
+                # Make the request
+                operation = client.create_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.CreateInstanceRequest, dict]):
                 The request object. CreateInstanceRequest creates an
@@ -431,7 +535,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, instance, instance_id])
         if request is not None and has_flattened_params:
@@ -491,6 +595,28 @@ class CloudFilestoreManagerAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the settings of a specific instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_update_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.UpdateInstanceRequest(
+                )
+
+                # Make the request
+                operation = client.update_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.UpdateInstanceRequest, dict]):
                 The request object. UpdateInstanceRequest updates the
@@ -528,7 +654,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([instance, update_mask])
         if request is not None and has_flattened_params:
@@ -590,6 +716,32 @@ class CloudFilestoreManagerAsyncClient:
         larger than the capacity of the backup (and also equal
         to or larger than the minimum capacity of the tier).
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_restore_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.RestoreInstanceRequest(
+                    source_backup="source_backup_value",
+                    name="name_value",
+                    file_share="file_share_value",
+                )
+
+                # Make the request
+                operation = client.restore_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.RestoreInstanceRequest, dict]):
                 The request object. RestoreInstanceRequest restores an
@@ -651,6 +803,29 @@ class CloudFilestoreManagerAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_delete_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.DeleteInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.DeleteInstanceRequest, dict]):
                 The request object. DeleteInstanceRequest deletes an
@@ -688,7 +863,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -744,6 +919,27 @@ class CloudFilestoreManagerAsyncClient:
         r"""Lists all backups in a project for either a specified
         location or for all locations.
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_list_backups():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.ListBackupsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_backups(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.ListBackupsRequest, dict]):
                 The request object. ListBackupsRequest lists backups.
@@ -774,7 +970,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -836,6 +1032,25 @@ class CloudFilestoreManagerAsyncClient:
     ) -> cloud_filestore_service.Backup:
         r"""Gets the details of a specific backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_get_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.GetBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_backup(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.GetBackupRequest, dict]):
                 The request object. GetBackupRequest gets the state of a
@@ -858,7 +1073,7 @@ class CloudFilestoreManagerAsyncClient:
                 A Cloud Filestore backup.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -916,6 +1131,30 @@ class CloudFilestoreManagerAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_create_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.CreateBackupRequest(
+                    parent="parent_value",
+                    backup_id="backup_id_value",
+                )
+
+                # Make the request
+                operation = client.create_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.CreateBackupRequest, dict]):
                 The request object. CreateBackupRequest creates a
@@ -965,7 +1204,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, backup, backup_id])
         if request is not None and has_flattened_params:
@@ -1024,6 +1263,29 @@ class CloudFilestoreManagerAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_delete_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.DeleteBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.DeleteBackupRequest, dict]):
                 The request object. DeleteBackupRequest deletes a
@@ -1061,7 +1323,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1117,6 +1379,28 @@ class CloudFilestoreManagerAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the settings of a specific backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_update_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.UpdateBackupRequest(
+                )
+
+                # Make the request
+                operation = client.update_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.UpdateBackupRequest, dict]):
                 The request object. UpdateBackupRequest updates
@@ -1152,7 +1436,7 @@ class CloudFilestoreManagerAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([backup, update_mask])
         if request is not None and has_flattened_params:
