@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -280,6 +282,73 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -330,50 +399,22 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, CloudFilestoreManagerTransport):
             # transport is a CloudFilestoreManagerTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -385,6 +426,15 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -409,6 +459,27 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         r"""Lists all instances in a project for either a
         specified location or for all locations.
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_list_instances():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.ListInstancesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_instances(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.ListInstancesRequest, dict]):
                 The request object. ListInstancesRequest lists
@@ -440,7 +511,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -493,6 +564,25 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> cloud_filestore_service.Instance:
         r"""Gets the details of a specific instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_get_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.GetInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.GetInstanceRequest, dict]):
                 The request object. GetInstanceRequest gets the state of
@@ -515,7 +605,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
                 A Cloud Filestore instance.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -568,6 +658,31 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         capacity of the backup (and also equal to or larger than
         the minimum capacity of the tier).
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_create_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.CreateInstanceRequest(
+                    parent="parent_value",
+                    instance_id="instance_id_value",
+                )
+
+                # Make the request
+                operation = client.create_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.CreateInstanceRequest, dict]):
                 The request object. CreateInstanceRequest creates an
@@ -612,7 +727,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, instance, instance_id])
         if request is not None and has_flattened_params:
@@ -672,6 +787,28 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> operation.Operation:
         r"""Updates the settings of a specific instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_update_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.UpdateInstanceRequest(
+                )
+
+                # Make the request
+                operation = client.update_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.UpdateInstanceRequest, dict]):
                 The request object. UpdateInstanceRequest updates the
@@ -709,7 +846,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([instance, update_mask])
         if request is not None and has_flattened_params:
@@ -771,6 +908,32 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         larger than the capacity of the backup (and also equal
         to or larger than the minimum capacity of the tier).
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_restore_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.RestoreInstanceRequest(
+                    source_backup="source_backup_value",
+                    name="name_value",
+                    file_share="file_share_value",
+                )
+
+                # Make the request
+                operation = client.restore_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.RestoreInstanceRequest, dict]):
                 The request object. RestoreInstanceRequest restores an
@@ -833,6 +996,29 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> operation.Operation:
         r"""Deletes an instance.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_delete_instance():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.DeleteInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.DeleteInstanceRequest, dict]):
                 The request object. DeleteInstanceRequest deletes an
@@ -870,7 +1056,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -926,6 +1112,27 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
         r"""Lists all backups in a project for either a specified
         location or for all locations.
 
+
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_list_backups():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.ListBackupsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_backups(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.ListBackupsRequest, dict]):
                 The request object. ListBackupsRequest lists backups.
@@ -956,7 +1163,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1009,6 +1216,25 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> cloud_filestore_service.Backup:
         r"""Gets the details of a specific backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_get_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.GetBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_backup(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.GetBackupRequest, dict]):
                 The request object. GetBackupRequest gets the state of a
@@ -1031,7 +1257,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
                 A Cloud Filestore backup.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1080,6 +1306,30 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> operation.Operation:
         r"""Creates a backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_create_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.CreateBackupRequest(
+                    parent="parent_value",
+                    backup_id="backup_id_value",
+                )
+
+                # Make the request
+                operation = client.create_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.CreateBackupRequest, dict]):
                 The request object. CreateBackupRequest creates a
@@ -1129,7 +1379,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, backup, backup_id])
         if request is not None and has_flattened_params:
@@ -1188,6 +1438,29 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> operation.Operation:
         r"""Deletes a backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_delete_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.DeleteBackupRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.DeleteBackupRequest, dict]):
                 The request object. DeleteBackupRequest deletes a
@@ -1225,7 +1498,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1281,6 +1554,28 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
     ) -> operation.Operation:
         r"""Updates the settings of a specific backup.
 
+        .. code-block:: python
+
+            from google.cloud import filestore_v1
+
+            def sample_update_backup():
+                # Create a client
+                client = filestore_v1.CloudFilestoreManagerClient()
+
+                # Initialize request argument(s)
+                request = filestore_v1.UpdateBackupRequest(
+                )
+
+                # Make the request
+                operation = client.update_backup(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.filestore_v1.types.UpdateBackupRequest, dict]):
                 The request object. UpdateBackupRequest updates
@@ -1316,7 +1611,7 @@ class CloudFilestoreManagerClient(metaclass=CloudFilestoreManagerClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([backup, update_mask])
         if request is not None and has_flattened_params:
